==> nextcloud-app-notes-4.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/sc.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Reading notes from filesystem has failed." : "Sa letura de is notas dae su filesystem est faddida.",
    "Error" : "Errore",
    "New note" : "Nota noa",
    "Distraction-free notes and writing" : "Notas sena disvios e iscritura ",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notas est un'aplicatzione pro pigare notas sena disvios pro [Nextcloud](https://www.nextcloud.com/). Frunit categorias pro un'organizatzione mègius e suportat sa formatatzione impreende sa sintassi [Markdown] (https://it.wikipedia.org/wiki/Markdown). Is notas si sarvant comente archìvios in su Nextcloud tuo, in manera chi ddas potzas visualizare e modificare cun cada cliente Nextcloud. In prus, un'[API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) a bandas cunsentit un'integrazione simpre in aplicatziones de is de tres partes (immoe bi sunt aplicatziones de notas pro [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) e sa [console](https://git.danielmoch.com/nncli/about) chi cunsentint un'intrada de àsiu a is notas de Nextcloud). Àteras funtzionalidades includent sa marcadura de is notas comente preferidas.",
    "Please see Nextcloud server log for details." : "Càstia is registros de su serbidore Nextcloud pro is detàllios.",
    "Deleted {title}" : "Eliminadu {title}",
    "Undo Delete" : "Annulla eliminatzione",
    "Note recovered" : "Nota ripristinada",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Bi sunt non sarvadas. Essida. Si lassas sa pàgina as a pèrdere totu is modìficas!",
    "_Deleted {number} note_::_Deleted {number} notes_" : [" {number} notas eliminadas","{number} notas eliminadas"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} notas ripristinadas","Notas {number} "],
    "Settings" : "Impostatziones",
    "Folder to store your notes" : "Cartella ue memorizare is notas tuas",
    "File extension for new notes" : "Estensione de is archìvios pro is notas noas",
    "Display mode for notes" : "Modalidades de visualizatzione de is notas",
    "Open in edit mode" : "Aberi in modalidade modìfica",
    "Open in preview mode" : "Aberi in modalidade anteprima",
    "No notes yet" : "Peruna nota ancora",
    "Insert image" : "Inserta·nche imàgine",
    "All notes" : "Totu is notas",
    "Categories" : "Categorias",
    "Loading …" : "Carrigamentu...",
    "Today" : "Oe",
    "Yesterday" : "Yesterday",
    "This week" : "Custa chida",
    "Last week" : "Sa chida colada",
    "This month" : "Custu mese",
    "Last month" : "Su mese passadu",
    "Rename" : "Torra a numenare",
    "Note's title" : "Tìtulu de sa nota",
    "Delete note" : "Elìmina nota",
    "Remove from favorites" : "Boga·nche dae preferidos",
    "Add to favorites" : "Agiunghe a is preferidos",
    "Error during preparing note for deletion." : "Errore in s'eliminatzione de sa nota.",
    "The note has been changed in another session. Please choose which version should be saved." : "Sa nota est istada modificada in un'àtera sessione. Sèbera cale versione est a sarvare.",
    "Use version from server" : "Impre versione de su serbidore",
    "Use current version" : "Imprea versione atuale",
    "Empty note" : "Nota bòida",
    "Write …" : "Iscrie ...",
    "Details" : "Detàllios",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modìfica ",
    "Preview" : "Anteprima",
    "Exit full screen" : "Essi dae ischermu intreu",
    "Full screen" : "Ischermu intreu",
    "Note is read-only. You cannot change it." : "Sa nota est a letura sola. Non faghet a dda cambiare.",
    "Save failed. Click to retry." : "Sarvamentu faddidu. Incarca pro bi torrare a proare.",
    "Update conflict. Click for resolving manually." : "Cunflitu de agiornamentu. Incarca pro isorvere a manu.",
    "Error from Nextcloud server: {msg}" : "Errore dae su serbidore de Nexcloud: {msg}",
    "Set category" : "Imposta categoria",
    "Category" : "Categoria",
    "Uncategorized" : "Sena categoria",
    "Click here to save manually" : "Incarca inoghe pro sarvare a manu",
    "Saving failed!" : "Sarvamentu faddidu!",
    "Last modified: {date}" : "Ùrtima modìfica: {date}",
    "Note has unsaved changes" : "Sa nota tenet modìficas non sarvadas",
    "Subcategory" : "Sutacategoria",
    "_%n word_::_%n words_" : ["%n  paràulas ","%n paràulas"],
    "_%n character_::_%n characters_" : ["%n caràteres","%n caràteres"],
    "Write down your thoughts without any distractions." : "Piga nota de is pensamentos tuos sena perunu disviu.",
    "Use Markdown markups to style your text." : "Imprea cuntrasignos Markdown pro formatare su testu tuo.",
    "Organize your notes in categories." : "Organiza is notas tuas in catègorias.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa s'aplicatzione pro su telefoneddu tuo pro intrare a is notas tuas dae totue.",
    "Android app" : "Aplicatzione Android",
    "iOS app" : "Aplicatzione iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Cumintza a iscrìere una nota incarchende subra de \"{newnote}\" in s'aplicatzione.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Podes creare sutacategorias impreende \"/\" comente tremenàrgiu e sa sutacategoria, pr. es. \"{parent}/{sub}\".",
    "Note not found." : "Nota no agatada.",
    "Note is locked." : "Sa nota est blocada.",
    "Insufficient storage." : "S'ispàtziu de archiviatzione non bastat.",
    "See JavaScript console and server log for details." : "Càstia sa consolla JavaScript e is registros de su serbidore pro is detàllios.",
    "Updating settings has failed." : "Agiornamentu de is impostatziones faddidu.",
    "Fetching notes for dashboard has failed." : "Recùperu de is notas pro su pannellu de controllu faddidu.",
    "Fetching notes has failed." : "Recùperu de is notas faddidu.",
    "Fetching note {id} has failed." : "Recùperu nota {id} faddidu.",
    "Refreshing note {id} has failed." : "L'agiornamentu de sa nota {id} faddidu.",
    "Renaming note {id} has failed." : "Sa torrada a numenare {id} faddida.",
    "Creating new note has failed." : "Creatzione nota noa faddida.",
    "Saving note {id} has failed." : "Su sarvamentu de sa nota {id} est faddidu.",
    "Updating title for note {id} has failed." : "S'agiornamentu de su tìtulu de sa nota {id} faddidu.",
    "Undo delete has failed for note {title}." : "Annullamentu eliminatzione faddidu pro sa nota {title}.",
    "Deleting note {id} has failed." : "Eliminatzione de sa nota {id} faddida.",
    "Toggling favorite for note {id} has failed." : "S'ativatzione comente preferidu de sa nota {id} faddida",
    "Updating the note's category has failed. Is the target directory writable?" : "S'agiornamentu de sa categoria de is notas faddidu. Sa cartella de destinu faghet a dda iscrìere?",
    "Updating the category for note {id} has failed." : "Agiornamentu de sa categoria pro sa nota {id} est faddidu.",
    "Development Mode" : "Modalidade de isvilupu",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Paret chu s'aplicatzione de is notas siat istada installada dae una fonte de isvilupu. Installa·dda imbetzes dae <a href=\"%1$s\">Butega de aplicatziones de Nextcloud</a> ufitziales. Si cheres compilare s'aplicatzione Note in autonomia, sighi is <a href=\"%2$s\">istrutziones pro isvilupadores</a>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-4.10.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/sc.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Reading notes from filesystem has failed." : "Sa letura de is notas dae su filesystem est faddida.",
    "Error" : "Errore",
    "New note" : "Nota noa",
    "Distraction-free notes and writing" : "Notas sena disvios e iscritura ",
    "Please see Nextcloud server log for details." : "Càstia is registros de su serbidore Nextcloud pro is detàllios.",
    "Deleted {title}" : "Eliminadu {title}",
    "Undo Delete" : "Annulla eliminatzione",
    "Note recovered" : "Nota ripristinada",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Bi sunt non sarvadas. Essida. Si lassas sa pàgina as a pèrdere totu is modìficas!",
    "_Deleted {number} note_::_Deleted {number} notes_" : [" {number} notas eliminadas","{number} notas eliminadas"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} notas ripristinadas","Notas {number} "],
    "Write down your thoughts without any distractions." : "Piga nota de is pensamentos tuos sena perunu disviu.",
    "Organize your notes in categories." : "Organiza is notas tuas in catègorias.",
    "Folder to store your notes" : "Cartella ue memorizare is notas tuas",
    "File extension for new notes" : "Estensione de is archìvios pro is notas noas",
    "Display mode for notes" : "Modalidades de visualizatzione de is notas",
    "Shortcuts" : "Incurtzaduras",
    "Action" : "Atzione",
    "Open in edit mode" : "Aberi in modalidade modìfica",
    "Open in preview mode" : "Aberi in modalidade anteprima",
    "Insert image" : "Inserta·nche immàgine",
    "All notes" : "Totu is notas",
    "Categories" : "Categorias",
    "No notes yet" : "Peruna nota ancora",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa s'aplicatzione pro su telefoneddu tuo pro intrare a is notas tuas dae totue.",
    "Rename" : "Torra a numenare",
    "Delete note" : "Elìmina nota",
    "Remove from favorites" : "Boga·nche dae preferidos",
    "Add to favorites" : "Agiunghe a is preferidos",
    "Error during preparing note for deletion." : "Errore in s'eliminatzione de sa nota.",
    "The note has been changed in another session. Please choose which version should be saved." : "Sa nota est istada modificada in un'àtera sessione. Sèbera cale versione est a sarvare.",
    "Use version from server" : "Impre versione de su serbidore",
    "Use current version" : "Imprea versione atuale",
    "Empty note" : "Nota bòida",
    "Write …" : "Iscrie ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modìfica ",
    "Preview" : "Anteprima",
    "Exit full screen" : "Essi dae ischermu intreu",
    "Full screen" : "Ischermu intreu",
    "Note is read-only. You cannot change it." : "Sa nota est a letura sola. Non faghet a dda cambiare.",
    "Save failed. Click to retry." : "Sarvamentu faddidu. Incarca pro bi torrare a proare.",
    "Update conflict. Click for resolving manually." : "Cunflitu de agiornamentu. Incarca pro isorvere a manu.",
    "Error from Nextcloud server: {msg}" : "Errore dae su serbidore de Nexcloud: {msg}",
    "Loading …" : "Carrigamentu...",
    "Today" : "Oe",
    "Yesterday" : "Yesterday",
    "This week" : "Custa chida",
    "Last week" : "Sa chida colada",
    "This month" : "Custu mese",
    "Last month" : "Su mese passadu",
    "Use Markdown markups to style your text." : "Imprea cuntrasignos Markdown pro formatare su testu tuo.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Cumintza a iscrìere una nota incarchende subra de \"{newnote}\" in s'aplicatzione.",
    "Note not found." : "Nota no agatada.",
    "Note is locked." : "Sa nota est blocada.",
    "Insufficient storage." : "S'ispàtziu de archiviatzione non bastat.",
    "See JavaScript console and server log for details." : "Càstia sa consolla JavaScript e is registros de su serbidore pro is detàllios.",
    "Updating settings has failed." : "Errore in s'atualizatzione de sa cunfiguratzione.",
    "Fetching notes for dashboard has failed." : "Recùperu de is notas pro su pannellu de controllu faddidu.",
    "Fetching notes has failed." : "Recùperu de is notas faddidu.",
    "Fetching note {id} has failed." : "Recùperu nota {id} faddidu.",
    "Refreshing note {id} has failed." : "L'agiornamentu de sa nota {id} faddidu.",
    "Renaming note {id} has failed." : "Sa torrada a numenare {id} faddida.",
    "Creating new note has failed." : "Creatzione nota noa faddida.",
    "Saving note {id} has failed." : "Su sarvamentu de sa nota {id} est faddidu.",
    "Updating title for note {id} has failed." : "S'agiornamentu de su tìtulu de sa nota {id} faddidu.",
    "Undo delete has failed for note {title}." : "Annullamentu eliminatzione faddidu pro sa nota {title}.",
    "Deleting note {id} has failed." : "Eliminatzione de sa nota {id} faddida.",
    "Toggling favorite for note {id} has failed." : "S'ativatzione comente preferidu de sa nota {id} faddida",
    "Updating the note's category has failed. Is the target directory writable?" : "S'agiornamentu de sa categoria de is notas faddidu. Sa cartella de destinu faghet a dda iscrìere?",
    "Updating the category for note {id} has failed." : "Agiornamentu de sa categoria pro sa nota {id} est faddidu.",
    "Uncategorized" : "Sena categoria",
    "Tasks" : "Fainas",
    "Development Mode" : "Modalidade de isvilupu",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Paret chu s'aplicatzione de is notas siat istada installada dae una fonte de isvilupu. Installa·dda imbetzes dae <a href=\"%1$s\">Butega de aplicatziones de Nextcloud</a> ufitziales. Si cheres compilare s'aplicatzione Note in autonomia, sighi is <a href=\"%2$s\">istrutziones pro isvilupadores</a>"
},
"nplurals=2; plural=(n != 1);");
